@@ -1,6 +1,7 @@
 OC.L10N.register(
     "contacts",
     {
+    "Import contacts" : "導入聯絡人",
     "Details" : "詳細資料",
     "All contacts" : "所有聯絡人",
     "Contacts" : "通訊錄",
@@ -71,7 +72,6 @@ OC.L10N.register(
     "Unable to change permissions" : "無法變更權限",
     "can edit" : "允許編輯",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
-    "Import contacts" : "導入聯絡人",
     "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
     "Select local file" : "選擇本機檔案",
     "Import from files" : "從檔案導入",
@@ -88,17 +88,16 @@ OC.L10N.register(
     "Sort by {sorting}" : "按 {sorting} 排序",
     "Manages" : "管理",
     "Oversees" : "監督",
+    "An error happened during the config change" : "配置更改期間發生錯誤",
     "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
     "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼 ...",
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
-    "An error happened during the config change" : "配置更改期間發生錯誤",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
-    "An error happened during description sync" : "描述同步期間發生錯誤",
-    "An error happened during name sync" : "名稱同步期間發生錯誤",
+    "An error happened while saving {fields}" : "儲存 {fields} 時發生了錯誤",
     "Team name" : "團隊名字",
     "Team owner" : "團隊所有者",
     "Edit" : "編輯",
@@ -154,8 +153,15 @@ OC.L10N.register(
     "Calendar events with you" : "與您分享的日曆活動",
     "Deck cards with you" : "與您分享的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "Confirm merging contacts" : "確認合併聯絡人",
+    "The selected contacts have conflicting information. Choose which information to keep" : "所選的聯絡人有衝突的資訊。請選擇要保留的資訊",
+    "Contacts can be merged" : "聯絡人可以合併",
+    "Groups" : "群組",
+    "Select groups to add the merged contact to" : "選擇要將合併的聯絡人添加到的群組",
+    "Merge contacts" : "合併聯絡人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Please select two editable contacts to merge" : "請選擇兩個可編輯的聯絡人進行合併",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
     "Search contacts …" : "搜尋聯絡人…",
     "Unselect {number}" : "取消選取 {number}",
@@ -163,7 +169,9 @@ OC.L10N.register(
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人添加到聯絡人群組。來自唯讀通訊錄的聯絡人，例如系統通訊錄，無法添加。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "新增至群組",
+    "Invite members to team" : "邀請成員加入團隊",
     "Search {types}" : "搜尋 {types}",
+    "Add guest" : "添加訪客",
     "Search for people to add" : "搜索要添加的人",
     "No results" : "沒有結果",
     "Add {type}" : "新增 {type}",
@@ -173,14 +181,6 @@ OC.L10N.register(
     "Local team" : "本地團隊",
     "This team will not be shared with the other instances of the global scale" : "此團隊不會與全球範圍內的其他實例共享",
     "Create team" : "創建團隊",
-    "Unable to get the results" : "無法得到結果",
-    "Some members could not be added" : "部分成員無法添加",
-    "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
-    "Loading members list …" : "正在加載成員清單 …",
-    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
-    "You currently have no access to the member list" : "您目前無權存取會員清單",
-    "Add to {circle}" : "添加到 {circle}",
-    "Pending" : "待定的",
     "Promote as sole owner" : "晉升作為唯一所有者",
     "Promote to {level}" : "晉升到 {level}",
     "Demote to {level}" : "降級到 {level}",
@@ -193,6 +193,14 @@ OC.L10N.register(
     "Reject membership request" : "拒絕會員申請",
     "Manage level" : "管理程度",
     "Remove member" : "移除成員",
+    "Unable to get the results" : "無法得到結果",
+    "Some members could not be added" : "部分成員無法添加",
+    "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
+    "Loading members list …" : "正在加載成員清單 …",
+    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
+    "You currently have no access to the member list" : "您目前無權存取會員清單",
+    "Add to {circle}" : "添加到 {circle}",
+    "Pending" : "待定的",
     "Select chart …" : "選擇圖表 ...",
     "Chart" : "圖表",
     "Select Date" : "選擇日期",
@@ -202,6 +210,8 @@ OC.L10N.register(
     "Select option" : "選擇選項",
     "Personal dates" : "個人日期",
     "Add property of this type" : "添加此類型的屬性",
+    "Member" : "成員",
+    "This is a read-only group managed by administrators. Group members can only view this group." : "此為由管理員管理的唯讀群組。群組成員僅能檢視此群組。",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
@@ -237,7 +247,6 @@ OC.L10N.register(
     "Group" : "群組",
     "Email" : "電郵地址",
     "Contact" : "聯絡人",
-    "Member" : "成員",
     "Moderator" : "主持人",
     "Admin" : "管理員",
     "Owner" : "擁有者",
@@ -253,7 +262,6 @@ OC.L10N.register(
     "users" : "用戶",
     "Users" : "用戶",
     "groups" : "群組",
-    "Groups" : "群組",
     "teams" : "團隊",
     "email addresses" : "電郵地址",
     "Email addresses" : "電郵地址",
@@ -322,18 +330,6 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人",
-    "Password protection" : "密碼保護",
-    "Team owned by {owner}" : "{owner} 擁有的團隊",
-    "Team settings" : "團隊設定",
-    "Description" : "描述",
-    "Team resources" : "團隊資源",
-    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
-    "Settings" : "Settings",
-    "Actions" : "操作",
-    "Team members" : "團隊成員",
-    "Add members" : "添加成員",
-    "Visibility" : "可見性",
-    "Team membership" : "團隊成員身分"
+    "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
